@@ -35,7 +35,7 @@ class Send_Mail:
             server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
         elif '@geekaso.com' in self.send_user:
             server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
-        elif 'admobile.top' in self.send_user:
+        elif '@admobile.top' in self.send_user:
             server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
         else:
             server = zmail.server(self.send_user, self.send_userpwd)
@@ -67,6 +67,10 @@ class Send_Mail:
 
         if '@qimai.cn' in self.send_user:
             server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
+        elif '@geekaso.com' in self.send_user:
+            server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
+        elif '@admobile.top' in self.send_user:
+            server = zmail.server(self.send_user, self.send_userpwd, smtp_host='smtp.exmail.qq.com', smtp_port=465)
         else:
             server = zmail.server(self.send_user, self.send_userpwd)
 
