@@ -124,7 +124,7 @@ class Line_Py:
         self.c_render = c
         return c
 
-    def line_render_qimai(self):
+    def line_render_qimai(self, sy_text='七麦数据'):
         c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
         # c = Line()
         c.add_xaxis(self.x_value)
@@ -145,6 +145,12 @@ class Line_Py:
                     color="#666", font_size=16, font_weight='normal', font_family='Microsoft YaHei'
                 ),
             ),
+            datazoom_opts=opts.DataZoomOpts(
+                is_show=self.is_zoom,
+                range_start=0,
+                range_end=100,
+                orient=self.is_orient  # 表示横轴可滑动还是纵轴可滑动；
+            ),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
             # legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon='circle'),
             legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
@@ -203,7 +209,7 @@ class Line_Py:
                                 left="center", top="center", z=100
                             ),
                             graphic_textstyle_opts=opts.GraphicTextStyleOpts(
-                                text="七麦数据",
+                                text=sy_text,
                                 # font="bold 26px Microsoft YaHei",
                                 font="26px Microsoft YaHei",
                                 graphic_basicstyle_opts=opts.GraphicBasicStyleOpts(
